---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Environment**

 - Your operating system and version:
 - Your python version:
 - Your PyTorch version:
 - How did you install python (e.g. apt or pyenv)? Did you use a virtualenv?:
 - Have you tried using latest bagua master (`python3 -m pip install git+https://github.com/BaguaSys/bagua.git -f https://repo.arrayfire.com/python/wheels/3.8.0/
`)?:

**Reproducing**

Please provide a [minimal working example](https://stackoverflow.com/help/mcve). This means the runnable code.

Please also write what exact commands are required to reproduce your results.

**Additional context**
Add any other context about the problem here.
